; ***************************************************************************
; *                                                                         *
; *  Copyright 1995 Symbios Logic Incorporated.  All rights reserved.       *
; *                                                                         *
; * This software was written by Symbios Logic Inc. to develop and test new *
; * products.  Symbios Logic assumes no liability for its use. This software*
; * is released to the public domain to illustrate certain programming      *
; * techniques for testing the 53c8xx chips                                 *
; *                                                                         *
; ***************************************************************************
;
;			  Name:  MAINT_SC.SS
;			 Title:  Validation test code 53C8XX Maintenance scripts
;		$Workfile:  $
;		$Revision:  $
;		 $Modtime:  $
;	  Programmer: Symbios Logic 
; Creation Date:  11/29/95
;
;  Version History
;  ---------------
;
;    Date    Who?  Description
;  --------  ----  -------------------------------------------------------
; #BeginRevision
;   11/29/95  SYM   Initial Revision.
; #EndRevision
;
; #BeginDescription
;
;   This file contains the SCSI Scripts used to execute single threaded
;   Maintenance IO's.  These would include TUR, Req. Sense, Inquiry, Read
;   capacity, Sync and Wide negotiation etc.  The commands mentioned have been
;   specifically tested with this script, but others should work as well.
;   This script is not optimized to do Read and Write instructions.
;   Disconnect, Tagged Command queuing and Wide are not supported by these
;   Scripts.
;
; #EndDescription
;
; -------------------------------------------------------------------------
;
;   $Header: $
;


ARCH 825

ABSOLUTE maint_cmd_complete=    0x00000000
ABSOLUTE not_command=           0x00000001
ABSOLUTE maint_unexpected_phase=0x00000002
ABSOLUTE not_msgo=              0x00000003
ABSOLUTE maint_bad_resel=       0x00000004

TABLE table0 \
		  maint_scsi_id= ID{0x33, 0x00, 0x00, 0x00},  \
		  maint_msgo_buf= {0x80}, \
		  maint_cmd_buf= {0x00, 0x00, 0x00, 0x00, 0x00, 0x00},  \
		  maint_stat_buf= ??, \
		  maint_msgi_buf= ??, \
		  maint_emsgi_buf= 4{??} \
		  maint_datai_buf= 0x24{??}

ENTRY maint_scsi

; this script is used to do a tur, req sense, inquiry and read capacity
; command and synchronous and wide negotiation

PROC MAINT_SCRIPT:
maint_scsi:
SELECT ATN FROM maint_scsi_id, REL(bad_reselect)	; select device

INT not_msgo, WHEN NOT MSG_OUT                     ; check for message_out
MOVE FROM maint_msgo_buf, WHEN MSG_OUT             ; Send identify

JUMP REL(decisions)

get_cmd:
MOVE FROM maint_cmd_buf, WHEN CMD                  ; Send command
JUMP REL(decisions)

get_status:
MOVE FROM maint_stat_buf, WHEN STATUS              ; Send status
JUMP REL(decisions)

get_msgin:
MOVE FROM maint_msgi_buf, WHEN MSG_IN              ; get Message in byte
JUMP REL(cmd_complete), IF 0x00                    ; end of command
JUMP REL(ext_msgi), IF 0x01                        ; extended message
CLEAR ACK
JUMP REL(decisions)

ext_msgi:
CLEAR ACK
MOVE FROM maint_emsgi_buf, WHEN MSG_IN             ; get extended message
CLEAR ACK
JUMP REL(decisions)

get_datain:
MOVE FROM maint_datai_buf, WHEN DATA_IN            ; get data
JUMP REL(decisions)

decisions:                                         ; make decision on what
JUMP REL(get_status), WHEN STATUS                  ; to do next
JUMP REL(get_msgin), WHEN MSG_IN
JUMP REL(get_datain), WHEN DATA_IN
JUMP REL(get_cmd), WHEN COMMAND
INT maint_unexpected_phase

cmd_complete:
MOVE SCNTL2 & 0x7F to SCNTL2
CLEAR ACK
WAIT DISCONNECT
INT maint_cmd_complete

bad_reselect:
INT maint_bad_resel
