/***************************************************************************
 *                                                                         *
 *  Copyright 1995 Symbios Logic Incorporated.  All rights reserved.       *
 *                                                                         *
 * This software was written by Symbios Logic Inc. to develop and test new *
 * products.  Symbios Logic assumes no liability for its use. This software*
 * is released to the public domain to illustrate certain programming      *
 * techniques for testing the 53c8xx chips                                 *
 *                                                                         *
 ***************************************************************************/

/*           Name:  TEST.C
 *          Title:  Validation test code main test function
 *      $Workfile:  $
 *      $Revision:  $
 *       $Modtime:  $
 *     Programmer:  (Put your name here)
 *  Creation Date:  (Put Creation date here)
 *
 *  Version History
 *  ---------------
 *
 *    Date    Who?  Description
 *  --------  ----  -------------------------------------------------------
#BeginRevision
 *  MM/DD/YY  XXX   Initial Revision.
#EndRevision
 *
#BeginDescription
 *
 * Put test description here
 *
#EndDescription
 *
 *-------------------------------------------------------------------------
 *
 *  $Header: $
 *
 */

/* Validation code tool include files, remove ones that are not needed */
/* Do not change the ordering of these include files */
#include "valtypes.h"
#include "gen_tool.h"
#include "pci.h"
#include "8xx_pci.h"
#include "8xx_tool.h"
#include "8xx_scsi.h"
#include "test.h"
#include "validate.h"
#include <stdio.h>
#include <time.h>
#include <stdlib.h>
#include <string.h>

/* function prototypes, do not remove this */
VINT test(pcidev_record *PCIDevice, cmdlineflags *flags);
void ParseCmdLine(cmdlineflags *flags, VINT argc, VCHAR **argv);

/* local function prototypes, do not remove this */
static void print_usage(void);

/* Global Variables, example only delete if not needed */
VUBYTE buffer1[0x4000];

/******************************************************************************
 Function: test
	Purpose : (Put test description here)
	Input: Pointer to pcidev_record data structure and pointer to
	       cmdlineflags data structure
	Output: (Summarize Passing and failing conditions here)
	Assumptions: none
	Restrictions: (Put Restrictions here)
	Other functions called: (Place other functions called here)

******************************************************************************/

VINT test(pcidev_record *PCIDevice, cmdlineflags *flags)

{

	/* Example data structures that may be needed, can be deleted if not */
	ti_entry sg_list[5];         /* scatter gather list */
	scsidev_record *SCSIDevice;  /* Pointer to SCSI device linked list  */
				     /* the init_scsi function returns this */
				     /* type of pointer                     */
	scsirw rw;                   /* SCSI Read/Write data structure */
				     /* Used for calls to do_Read6/10  */
				     /* do_Write6/10 and do_rw         */
	VINT ret_value;              /* Return value from do_read6     */

	/* Verbose mode? */
	if (!flags->verbose)
		fprintf(stdout, "-v option OFF, all output going to TEST.LOG\n");
	
	/* Initialize the SCSI bus */
	SCSIDevice = init_scsi(PCIDevice, 1, 1);

	if (SCSIDevice == NULL)
	{
		WriteLog(LOG_PASS, LOG_DETAIL, "No SCSI Devices found!!!\n\n", NULL);
		return(0);
	}
	WriteLog(LOG_PASS, LOG_DETAIL, "Doing 6 byte read of LBA 0...", NULL);

	/* Generate a random Scatter Gather List */
	randomize();
	GenRandSG(buffer1, sizeof(buffer1), sg_list, 5);

	/* Fill in RW data structure */
	rw.sg_entry = sg_list;
	rw.sel_info = SCSIDevice->sel_info;
	rw.lba = 0;
	rw.blk_count = sizeof(buffer1)/SCSIDevice->blksize;
	rw.id_count = 1;
	rw.sg_count = 5;
	rw.enable_auto_rqs = 1;
	rw.id_buf[0] = 0xC0;

	/* Do the Read */
	ret_value = do_Read6(PCIDevice, &rw);
	
	/* Check the results */
	if (ret_value == SCSI_GOOD)
	{
		WriteLog(LOG_PASS, LOG_DETAIL, "PASS\n\n", NULL);
		return(1);
	}
	else
	{
		WriteLog(LOG_PASS, LOG_DETAIL, "FAIL\n", NULL);
		if (ret_value == SCSI_POLLTO)
			WriteLog(LOG_PASS, LOG_DETAIL, "Interrupt Poll Timeout.\n\n", NULL);
		else if (ret_value ==SCSI_SELECTTO)
			WriteLog(LOG_PASS, LOG_DETAIL, "SCSI Selection Timeout.\n\n", NULL);
		else
		{
			WriteLog(LOG_PASS, LOG_DETAIL, "Command failed.\n", NULL);
			WriteLog(LOG_PASS, LOG_DETAIL, "See do_read6 documentation in "
				"TAZ_DEF2.DOC(.TXT)\n\n", NULL);
		}

		return(0);
	}

}


/******************************************************************************
 Function: ParseCmdLine
	Purpose : To parse command line options
	Input: Pointer to cmdlineflags structure, command line argument count
		argc and command line string pointer argv.
	Output: Initialized cmdlineflags data structure
	Assumptions: (Place assumptions here)
	Restrictions: (Place restrictions here)
	Other functions called:  print_usage to print the usage screen and exit  
				 strncpy to copy log file name to a string
				 (Place other functions called here)

******************************************************************************/

void ParseCmdLine(cmdlineflags *flags, VINT argc, VCHAR **argv)
{

	VINT i;
	VCHAR **endptr;

	/* set flags to a default value */
	flags->all = 0;
	flags->verbose = 0; /* **** DO NOT REMOVE THIS COMMAND LINE OPTION!!! **** */
	flags->printti = 0;
	flags->param_sub = 0;
	flags->testnum = -1;
	flags->lowtest = -1;
	flags->hightest = -1;
	flags->device = -1; /* **** DO NOT REMOVE THIS COMMAND LINE OPTION!!! **** */
	flags->ud_flag1 = 0;
	flags->ud_flag2 = 0;
	flags->ud_flag3 = 0;


	/* did user want defaults changed */
	if (argc > 1)
	{
		for (i=1; i<argc; i++)
		{
			if (argv[i][0] == '?') print_usage();
			if (argv[i][0] == '-' || argv[i][0] == '/')
			{
				switch (argv[i][1])
				{
					case 'a':       /* run all tests all variations */
					{
						flags->all = 1;
						break;
					}
					/* **** DO NOT REMOVE THIS COMMAND LINE OPTION!!! **** */
					case 'v':       /* verbose mode/print to screen */
					{
						flags->verbose = 1;
						break;
					}
					case '?':       /* print usage */
					{
						print_usage();
						break;
					}
					case 'p':       /* print test info/help */
					{
						flags->printti = 1;
						break;
					}
					case 'b':       /* run a subset of the parameters if possible */
					{
						flags->param_sub = 1;
						break;
					}
					/* **** DO NOT REMOVE THIS COMMAND LINE OPTION!!! **** */
					case 'd':       /* select a specific PCI device to use */
					{
						flags->device = argv[i][2] - '0';  /* select specific */
						break;                             /* device */
					}
					case 't':       /* specify a specific test to run */
					{
						flags->testnum = (VINT) strtol(&argv[i][2], NULL, 10);
						break;
					}
					case 'r':       /* range of tests to run */
					{
						flags->lowtest = (VINT) strtol(&argv[i][2], endptr, 10);
						*endptr += 1;
						flags->hightest = (VINT) strtol(*endptr, NULL, 10);
						break;
					}
					/* **** DO NOT REMOVE THIS COMMAND LINE OPTION!!! **** */
					case 'l':       /* log file name */
					{
						strncpy(logfilename_ptr, &argv[i][2], 13);
						break;
					}
					case 'x':       /* test writer defined flag #1 */
					{
						flags->ud_flag1 = 1;  /* enable flag1 */
						break;
					}
					case 'y':       /* test writer defined flag #2 */
					{
						flags->ud_flag2 = 1;  /* enable flag2 */
						break;
					}
					case 'z':       /* test writer defined flag #3 */
					{
						flags->ud_flag3 = 1;  /* enable flag3 */
						break;
					}
					default: print_usage();
				}
			}
			else
			{
				print_usage();
			}
		}
	}
}

/******************************************************************************
 Function: print_usage
	Purpose : To print the program usage screen and exit
	Input: Nothing
	Output: Usage screen printed. Function does not return.
	Assumptions: None
	Restrictions: None
	Other functions called:  fprintf to print to the screen  
				 exit to exit the program
******************************************************************************/

static void print_usage(void)
{

	fprintf(stdout,"Symbios Logic Validation Test Code\n");
	fprintf(stdout,"Part(s) under test: %s\n", DEVICE_UNDER_TEST);
	fprintf(stdout,"\n%s Test, Version %s\n", TEST_NAME, TEST_VERSION);
	fprintf(stdout,"Validation Core Version %s\n", CORE_VERSION);
	fprintf(stdout,"Usage:  test (- or /)[avpbdtrlxyz]\n");
	fprintf(stdout,"        a - enable all tests all variations\n");
	fprintf(stdout,"        v - verbose mode\n");
	fprintf(stdout,"        p - print specific test info/help\n");
	fprintf(stdout,"        b - run a subset of the test parameters if possible\n");
	fprintf(stdout,"        dn - use device 'n' as the test device (no spaces)\n");
	fprintf(stdout,"        tn - run test number 'n' (no spaces)\n");
	fprintf(stdout,"        rx-y - run from test x to test y (no spaces)\n");
	fprintf(stdout,"        lxxx - specify log file name (default = test.log)\n");
	fprintf(stdout,"        x - enable flag1\n");
	fprintf(stdout,"        y - enable flag2\n");
	fprintf(stdout,"        z - enable flag3\n");
	fprintf(stdout,"        ? - print this\n\n");
	exit(1);

}

